==> nextcloud-19.0.3.tgz: nextcloud/apps/comments/l10n/hr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentari",
    "You commented" : "Vi ste komentirali",
    "%1$s commented" : "Komentirao je %1$s",
    "{author} commented" : "{autor} je komentirao",
    "You commented on %1$s" : "Vi ste komentirali %1$s",
    "You commented on {file}" : "Komentirali ste {file}",
    "%1$s commented on %2$s" : "%1$s je komentirao %2$s",
    "{author} commented on {file}" : "{author} je komentirao {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentari</strong> za datoteke",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Spomenuti ste u „{file}”, u komentaru korisnika koji je nakon toga izbrisan",
    "{user} mentioned you in a comment on “{file}”" : "{user} vas je spomenuo u komentaru na „{file}”",
    "Files app plugin to add comments to files" : "Dodatak za aplikaciju Datoteke za dodavanje komentara na datoteke",
    "Edit comment" : "Uredi komentar",
    "Delete comment" : "Izbriši komentar",
    "New comment …" : "Novi komentar…",
    "Post" : "Objavi",
    "Cancel" : "Odustani",
    "[Deleted user]" : "[Izbrisan korisnik]",
    "No comments yet, start the conversation!" : "Još nema komentara, započnite razgovor!",
    "More comments …" : "Više komentara...",
    "Save" : "Spremi",
    "Allowed characters {count} of {max}" : "Dopušteni znakovi {count} od {max}",
    "Error occurred while retrieving comment with ID {id}" : "Došlo je do pogreške prilikom dohvaćanja komentara s ID-om {id}",
    "Error occurred while updating comment with id {id}" : "Došlo je do pogreške prilikom ažuriranja komentara s ID-om {id}",
    "Error occurred while posting comment" : "Došlo je do pogreške prilikom objavljivanja komentara",
    "_%n unread comment_::_%n unread comments_" : ["%n nepročitani komentar","%n nepročitanih komentara","%n nepročitanih komentara"],
    "_1 new comment_::_{unread} new comments_" : ["1 novi komentar","{unread} novih komentara","{unread} novih komentara"],
    "Comment" : "Komentar"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-19.0.6.tgz: nextcloud/apps/comments/l10n/hr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentari",
    "You commented" : "Vi ste komentirali",
    "%1$s commented" : "Komentirao je %1$s",
    "{author} commented" : "{autor} je komentirao",
    "You commented on %1$s" : "Vi ste komentirali %1$s",
    "You commented on {file}" : "Komentirali ste {file}",
    "%1$s commented on %2$s" : "%1$s je komentirao %2$s",
    "{author} commented on {file}" : "{author} je komentirao {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentari</strong> za datoteke",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Spomenuti ste u „{file}”, u komentaru korisnika koji je nakon toga izbrisan",
    "{user} mentioned you in a comment on “{file}”" : "{user} vas je spomenuo u komentaru na „{file}”",
    "Files app plugin to add comments to files" : "Dodatak za aplikaciju Datoteke za dodavanje komentara na datoteke",
    "Edit comment" : "Uredi komentar",
    "Delete comment" : "Izbriši komentar",
    "No comments yet, start the conversation!" : "Još nema komentara, započnite razgovor!",
    "Retry" : "Pokušaj ponovno",
    "_%n unread comment_::_%n unread comments_" : ["%n nepročitani komentar","%n nepročitanih komentara","%n nepročitanih komentara"],
    "_1 new comment_::_{unread} new comments_" : ["1 novi komentar","{unread} novih komentara","{unread} novih komentara"],
    "Comment" : "Komentar",
    "Comment deleted" : "Komentar izbrisan",
    "New comment …" : "Novi komentar…",
    "Post" : "Objavi",
    "Cancel" : "Odustani",
    "[Deleted user]" : "[Izbrisan korisnik]",
    "More comments …" : "Više komentara...",
    "Save" : "Spremi",
    "Allowed characters {count} of {max}" : "Dopušteni znakovi {count} od {max}",
    "Error occurred while retrieving comment with ID {id}" : "Došlo je do pogreške prilikom dohvaćanja komentara s ID-om {id}",
    "Error occurred while updating comment with id {id}" : "Došlo je do pogreške prilikom ažuriranja komentara s ID-om {id}",
    "Error occurred while posting comment" : "Došlo je do pogreške prilikom objavljivanja komentara"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
